==> haskell-aeson-qq-0.8.2-49-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-qq
version: 0.8.2
id: aeson-qq-0.8.2-rNCetNMKwNLgFwfR2LgbP
key: aeson-qq-0.8.2-rNCetNMKwNLgFwfR2LgbP
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
author: Oscar Finnsson
homepage: https://github.com/sol/aeson-qq#readme
synopsis: JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.
    .
    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature
    .
    >aesonQQ :: QuasiQuoter
    .
    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>
category: JSON
abi: b06144c182e0fd92ab62fcab3b2354b5
exposed: True
exposed-modules:
    Data.Aeson.QQ
hidden-modules: Data.JSON.QQ Paths_aeson_qq
import-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-qq-0.8.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-qq-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/aeson-qq-0.8.2
hs-libraries: HSaeson-qq-0.8.2-rNCetNMKwNLgFwfR2LgbP
depends:
    base-4.11.1.0 base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    text-1.2.3.0 attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    aeson-1.3.1.1-ArWpZy1DbZ6Lxt3YgJqPBO parsec-3.1.13.0
    template-haskell-2.13.0.0
    haskell-src-meta-0.8.0.3-2ZnWbpI5fKX7AzfNfuipe2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=d62b8bf62b1a5e2bfe5d3dedbe6980ab
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ=b6c55238d5ca948928baa2c3b9c37177
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             aeson-1.3.1.1-ArWpZy1DbZ6Lxt3YgJqPBO=63ce14baf2a7c28abbc692d9e7dd92cc
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             haskell-src-meta-0.8.0.3-2ZnWbpI5fKX7AzfNfuipe2=0239169cea56d5906d094c8741f7972c
haddock-interfaces: /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html: /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-qq-0.8.2-51-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-qq
version: 0.8.2
id: aeson-qq-0.8.2-2ojVXhrUYis45WuflPj1vo
key: aeson-qq-0.8.2-2ojVXhrUYis45WuflPj1vo
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
author: Oscar Finnsson
homepage: https://github.com/sol/aeson-qq#readme
synopsis: JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.
    .
    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature
    .
    >aesonQQ :: QuasiQuoter
    .
    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>
category: JSON
abi: 6df414fb835497ba5afa923b4f74f579
exposed: True
exposed-modules:
    Data.Aeson.QQ
hidden-modules: Data.JSON.QQ Paths_aeson_qq
import-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-qq-0.8.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-qq-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/aeson-qq-0.8.2
hs-libraries: HSaeson-qq-0.8.2-2ojVXhrUYis45WuflPj1vo
depends:
    base-4.11.1.0 base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    text-1.2.3.0 attoparsec-0.13.2.2-9zRGjV3As3w1B2ujiZf4yU
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    aeson-1.3.1.1-6MYzDDA2vlE42OFIDFWYr5 parsec-3.1.13.0
    template-haskell-2.13.0.0
    haskell-src-meta-0.8.0.3-BLc3eLS2wmqAOYNSFgLpzH
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=d62b8bf62b1a5e2bfe5d3dedbe6980ab
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             attoparsec-0.13.2.2-9zRGjV3As3w1B2ujiZf4yU=970180ace34b66d93bd5b25ba2c2a659
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             aeson-1.3.1.1-6MYzDDA2vlE42OFIDFWYr5=b260fa08272c0cac5c6fef6b1f493cce
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             haskell-src-meta-0.8.0.3-BLc3eLS2wmqAOYNSFgLpzH=e1959dc53f6cf4a335cd9f0a0d595da5
haddock-interfaces: /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html: /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
